@@ -3,6 +3,7 @@ import pickle
 import time
 import logging
 import json
+import unicodedata
 import yaml
 from pathlib import Path
 
@@ -57,7 +58,8 @@ class Lupusec:
             self._history_cache = pickle.load(
                 open(home + "/" + CONST.HISTORY_CACHE_NAME, "rb")
             )
-        except (OSError, IOError) as e:
+        except Exception as e:
+            _LOGGER.debug(e)
             self._history_cache = []
             pickle.dump(
                 self._history_cache, open(home + "/" + CONST.HISTORY_CACHE_NAME, "wb")
@@ -88,6 +90,9 @@ class Lupusec:
             self.api_url + action, data=params, headers=self.headers
         )
 
+    def remove_control_characters(self, s):
+        return "".join(ch for ch in s if unicodedata.category(ch)[0]!="C")
+
     def clean_json(self, textdata):
         _LOGGER.debug("Input for clean json" + textdata)
         if self.model == 1:
@@ -102,7 +107,7 @@ class Lupusec:
                 )
             return textdata
         else:
-            return json.loads(textdata)
+            return json.loads(self.remove_control_characters(textdata))
 
     def get_power_switches(self):
         stampNow = time.time()
@@ -129,25 +134,31 @@ class Lupusec:
         return self._cachePss
 
     def get_sensors(self):
-        stamp_now = time.time()
-        if self._cacheSensors is None or stamp_now - self._cacheStampS > 2.0:
-            self._cacheStampS = stamp_now
-            response = self._request_get(self.api_sensors)
-            response = self.clean_json(response.text)["senrows"]
-            sensors = []
-            for device in response:
-                device["status"] = device["cond"]
-                device["device_id"] = device[self.api_device_id]
-                device.pop("cond")
-                device.pop(self.api_device_id)
-                if not device["status"]:
-                    device["status"] = "Geschlossen"
-                else:
-                    device["status"] = None
-                sensors.append(device)
-            self._cacheSensors = sensors
+            stamp_now = time.time()
+            if self._cacheSensors is None or stamp_now - self._cacheStampS > 2.0:
+                self._cacheStampS = stamp_now
+                response = self._request_get(self.api_sensors)
+                response = self.clean_json(response.text)["senrows"]
+                sensors = []
+                for device in response:
+                    if self.model == 1:
+                        device["status"] = device["cond"]
+                    else:
+                        if "openClose" in device:
+                            device["status"] = device["openClose"]
+                            device.pop("openClose")
+                    device["device_id"] = device[self.api_device_id]
+                    device.pop("cond")
+                    device.pop(self.api_device_id)
+                    if device["status"] == "{WEB_MSG_DC_OPEN}":
+                        print("yes is open " + device["name"])
+                        device["status"] = "Offen"
+                    if device["status"] == "{WEB_MSG_DC_CLOSE}" or device["status"] == "0":
+                        device["status"] = "Geschlossen"
+                    sensors.append(device)
+                self._cacheSensors = sensors
 
-        return self._cacheSensors
+            return self._cacheSensors
 
     def get_panel(
         self,
@@ -211,7 +222,7 @@ class Lupusec:
                 if device:
                     device.update(deviceJson)
                 else:
-                    device = self.newDevice(deviceJson, self)
+                    device = newDevice(deviceJson, self)
 
                     if not device:
                         _LOGGER.info("Device is unknown")
@@ -246,7 +257,7 @@ class Lupusec:
                     if device:
                         device.update(deviceJson)
                     else:
-                        device = self.newDevice(deviceJson, self)
+                        device = newDevice(deviceJson, self)
                         if not device:
                             _LOGGER.info("Device is unknown")
                             continue
